@@ -3,6 +3,6 @@ from django.http import HttpResponse
 
 def flash_context(request):
     flash = None
-    if 'djangoflashcookie' in request.COOKIES:
-        flash = simplejson.loads(request.COOKIES['djangoflashcookie'])
+    if 'flashcookie' in request.COOKIES:
+        flash = simplejson.loads(request.COOKIES['flashcookie'])
     return {'flash': flash}
