@@ -22,7 +22,7 @@ class FlashMiddleware(object):
         serialize data to json and put it in coockies
         """
         data = simplejson.dumps(request.flash)
-        response.set_cookie('djangoflashcookie', data)
+        response.set_cookie('flashcookie', data)
 
     def process_request(self, request):
         """
@@ -35,8 +35,8 @@ class FlashMiddleware(object):
         if request.flash have data, put it to cookies,
         delete previous cookie if no data in request.flash
         """
-        if hasattr(request, 'djangoflashcookie') and len(request.flash):
+        if hasattr(request, 'flash') and len(request.flash):
             self._set_messages(request, response)
         else:
-            response.delete_cookie('djangoflashcookie')
+            response.delete_cookie('flashcookie')
         return response
